@@ -1,7 +1,7 @@
 package Bencher::Scenario::ComparisonOps;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,11 +29,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::ComparisonOps
+Bencher::Scenario::ComparisonOps - Benchmark comparison operators
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::ComparisonOps (from Perl distribution Bencher-Scenario-ComparisonOps), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::ComparisonOps (from Perl distribution Bencher-Scenario-ComparisonOps), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -83,18 +83,18 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m ComparisonOps >>):
 
- +-----+------------------------------------------------+----------+---------+---------+---------+
- | seq | name                                           | rate     | time    | errors  | samples |
- +-----+------------------------------------------------+----------+---------+---------+---------+
- | 2   | {dataset=>undef,participant=>"1k-streq-len3"}  | 1.02e+04 | 98.3μs  | 8e-08   | 20      |
- | 1   | {dataset=>undef,participant=>"1k-streq-len1"}  | 1.06e+04 | 94.36μs | 2.6e-08 | 21      |
- | 3   | {dataset=>undef,participant=>"1k-streq-len10"} | 1.06e+04 | 94.34μs | 2.7e-08 | 20      |
- | 0   | {dataset=>undef,participant=>"1k-numeq"}       | 1.31e+04 | 76.2μs  | 2.7e-08 | 20      |
- +-----+------------------------------------------------+----------+---------+---------+---------+
+ +----------------+-----------+-----------+------------+---------+---------+
+ | participant    | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +----------------+-----------+-----------+------------+---------+---------+
+ | 1k-streq-len10 |   17000   |   59      |    1       | 2.4e-07 |      20 |
+ | 1k-streq-len3  |   17413.8 |   57.4256 |    1.03335 | 3.5e-11 |      28 |
+ | 1k-streq-len1  |   17718.1 |   56.4395 |    1.0514  |   0     |      20 |
+ | 1k-numeq       |   20903   |   47.8399 |    1.2404  |   0     |      22 |
+ +----------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
